# pYPKa_A_ScXKS1

Plan for the construction of E. coli vector pYPKa_A_ScXKS1

# Step 1 PCR of the insert

PCR with primers pfw1803 & prv1803 and template ScXKS1_template results in a 1805bp PCR product

Primers annealing on template:

      5ATGTTGTGTTCAGTAATTCA...TGGAAAAGACTCTCATCTAA3
                              |||||||||||||||||||| tm 45.0 (dbd) 55.7
                             3ACCTTTTCTGAGAGTAGATT5
    5aaATGTTGTGTTCAGTAATTCA3
       |||||||||||||||||||| tm 44.8 (dbd) 54.6
      3TACAACACAAGTCATTAAGT...ACCTTTTCTGAGAGTAGATT5

Suggested PCR programs for Taq polymerase and for Polymerases with DNA binding domain:

    Taq (rate 30 nt/s) 35 cycles             |1805bp
    95.0°C    |95.0°C                 |      |SantaLucia 1998
    |_________|_____          72.0°C  |72.0°C|SaltC 50mM
    | 03min00s|30s  \         ________|______|
    |         |      \ 52.0°C/ 0min54s| 5min |
    |         |       \_____/         |      |
    |         |         30s           |      |4-12°C

# Step 2 Vector digestion and cloning

Clone the PCR product in pYPKa digested with AjiI resulting in pYPKa_A_ScXKS1

# Step 3 Diagnostic PCR confirmation

Confirm the structure of the pYPKa_A_ScXKS1 using primers 468, 342 and pfw1803 in a multiplex PCR reaction.

Expected PCR products sizes from 468, 342 and pfw1803 (bp):

pYPKa with insert in correct orientation: 2571, 2521
pYPKa with insert in reverse orientation: 2571, 1855
Empty pYPKa clone : 766